@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2004, 2005, 2006 Joe Walnes.
- * Copyright (C) 2006, 2007, 2008, 2010, 2011, 2012, 2013, 2014, 2015, 2016 XStream Committers.
+ * Copyright (C) 2006, 2007, 2008, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2024 XStream Committers.
  * All rights reserved.
  *
  * The software in this package is published under the terms of the BSD
@@ -375,7 +375,7 @@ public class SerializableConverter extends AbstractReflectionConverter {
             }
 
             public void defaultReadObject() {
-                if (serializationMembers.getSerializablePersistentFields(currentType[0]) != null) {
+                if (serializationMembers.hasSerializablePersistentFields(currentType[0])) {
                     readFieldsFromStream();
                     return;
                 }
