@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013, 2014, 2017, 2018, 2020, 2021, 2022 XStream Committers.
+ * Copyright (C) 2013, 2014, 2017, 2018, 2020, 2021, 2022, 2024 XStream Committers.
  * All rights reserved.
  *
  * The software in this package is published under the terms of the BSD
@@ -26,8 +26,10 @@ import java.util.LinkedHashSet;
 import java.util.Map;
 import java.util.Set;
 
+import com.thoughtworks.xstream.XStream;
 import com.thoughtworks.xstream.converters.ConversionException;
 import com.thoughtworks.xstream.core.JVM;
+import com.thoughtworks.xstream.io.binary.BinaryStreamDriver;
 import com.thoughtworks.xstream.security.AnyTypePermission;
 import com.thoughtworks.xstream.security.ForbiddenClassException;
 import com.thoughtworks.xstream.security.InputManipulationException;
@@ -123,6 +125,98 @@ public class SecurityVulnerabilityTest extends AbstractAcceptanceTest {
         }
     }
 
+    public void testExplicitlyConvertSwingUIDefaults() {
+        if (JVM.isVersion(7)) {
+            final String xml = ""
+                + "<hashtable>\n"
+                + "  <entry>\n"
+                + "    <javax.swing.UIDefaults_-TextAndMnemonicHashMap serialization=\"custom\">\n"
+                + "      <unserializable-parents/>\n"
+                + "      <map>\n"
+                + "        <default>\n"
+                + "          <loadFactor>1.0</loadFactor>\n"
+                + "          <threshold>12</threshold>\n"
+                + "        </default>\n"
+                + "        <int>16</int>\n"
+                + "        <int>1</int>\n"
+                + "        <javax.activation.MimeTypeParameterList>\n"
+                + "          <parameters class=\"javax.swing.UIDefaults\" serialization=\"custom\">\n"
+                + "            <unserializable-parents/>\n"
+                + "            <hashtable>\n"
+                + "              <default>\n"
+                + "                <loadFactor>0.75</loadFactor>\n"
+                + "                <threshold>525</threshold>\n"
+                + "              </default>\n"
+                + "              <int>700</int>\n"
+                + "              <int>1</int>\n"
+                + "              <string>1</string>\n"
+                + "              <javax.swing.UIDefaults_-ProxyLazyValue>\n"
+                + "                <className>sun.reflect.misc.MethodUtil</className>\n"
+                + "                <methodName>invoke</methodName>\n"
+                + "                <args>\n"
+                + "                  <method>\n"
+                + "                    <class>sun.reflect.misc.MethodUtil</class>\n"
+                + "                    <name>invoke</name>\n"
+                + "                    <parameter-types>\n"
+                + "                      <class>java.lang.reflect.Method</class>\n"
+                + "                      <class>java.lang.Object</class>\n"
+                + "                      <class>[Ljava.lang.Object;</class>\n"
+                + "                    </parameter-types>\n"
+                + "                  </method>\n"
+                + "                  <object/>\n"
+                + "                  <object-array>\n"
+                + "                    <method>\n"
+                + "                      <class>com.thoughtworks.acceptance.SecurityVulnerabilityTest$Exec</class>\n"
+                + "                      <name>exec</name>\n"
+                + "                      <parameter-types/>\n"
+                + "                    </method>\n"
+                + "                    <com.thoughtworks.acceptance.SecurityVulnerabilityTest_-Exec/>\n"
+                + "                    <object-array/>\n"
+                + "                  </object-array>\n"
+                + "                </args>\n"
+                + "              </javax.swing.UIDefaults_-ProxyLazyValue>\n"
+                + "            </hashtable>\n"
+                + "            <javax.swing.UIDefaults>\n"
+                + "              <default>\n"
+                + "                <defaultLocale>zh_CN</defaultLocale>\n"
+                + "                <resourceCache/>\n"
+                + "              </default>\n"
+                + "            </javax.swing.UIDefaults>\n"
+                + "          </parameters>\n"
+                + "        </javax.activation.MimeTypeParameterList>\n"
+                + "        <null/>\n"
+                + "      </map>\n"
+                + "    </javax.swing.UIDefaults_-TextAndMnemonicHashMap>\n"
+                + "    <int>1</int>\n"
+                + "  </entry>\n"
+                + "  <entry>\n"
+                + "    <javax.swing.UIDefaults_-TextAndMnemonicHashMap serialization=\"custom\">\n"
+                + "      <unserializable-parents/>\n"
+                + "      <map>\n"
+                + "        <default>\n"
+                + "          <loadFactor>1.0</loadFactor>\n"
+                + "          <threshold>12</threshold>\n"
+                + "        </default>\n"
+                + "        <int>16</int>\n"
+                + "        <int>1</int>\n"
+                + "        <javax.activation.MimeTypeParameterList reference=\"../../../../entry/javax.swing.UIDefaults_-TextAndMnemonicHashMap/map/javax.activation.MimeTypeParameterList\"/>\n"
+                + "        <null/>\n"
+                + "      </map>\n"
+                + "    </javax.swing.UIDefaults_-TextAndMnemonicHashMap>\n"
+                + "    <int>1</int>\n"
+                + "  </entry>\n"
+                + "</hashtable>";
+
+            xstream.allowTypes(new String[]{
+                "javax.activation.MimeTypeParameterList", "javax.swing.UIDefaults$ProxyLazyValue"});
+
+            assertEquals(0, BUFFER.length());
+            final Hashtable hashtable = (Hashtable)xstream.fromXML(xml);
+            assertEquals(JVM.isVersion(16) ? "" : "Executed!", BUFFER.toString());
+            assertNotNull(hashtable);
+        }
+    }
+
     public static class Exec {
 
         public void exec() {
@@ -224,7 +318,7 @@ public class SecurityVulnerabilityTest extends AbstractAcceptanceTest {
         }
     }
 
-    public void testCannotInjectManipulatedByteArryInputStream() {
+    public void testCannotInjectManipulatedByteArrayInputStream() {
         xstream.alias("bais", ByteArrayInputStream.class);
         final String xml = ""
             + "<bais>\n"
@@ -242,7 +336,7 @@ public class SecurityVulnerabilityTest extends AbstractAcceptanceTest {
         }
     }
 
-    public void testExplicitlyUnmarshalEndlessByteArryInputStream() {
+    public void testExplicitlyUnmarshalEndlessByteArrayInputStream() {
         xstream.alias("bais", ByteArrayInputStream.class);
         xstream.allowTypes(new Class[]{ByteArrayInputStream.class});
 
@@ -453,4 +547,21 @@ public class SecurityVulnerabilityTest extends AbstractAcceptanceTest {
             assertTrue(e.getMessage().indexOf("Stack Overflow") >= 0);
         }
     }
+
+    public void testStackOverflowInBinaryStreamReaderWithManipulatedInputData() {
+        final byte[] byteArray = new byte[36000];
+        for (int i = 0; i < byteArray.length / 4; i++) {
+            byteArray[i * 4] = 10;
+            byteArray[i * 4 + 1] = -127;
+            byteArray[i * 4 + 2] = 0;
+            byteArray[i * 4 + 3] = 0;
+        }
+
+        try {
+            xstream = new XStream(new BinaryStreamDriver());
+            xstream.fromXML(new ByteArrayInputStream(byteArray));
+        } catch (final InputManipulationException e) {
+            assertTrue(e.getMessage().indexOf("two mapping tokens") >= 0);
+        }
+    }
 }
