@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006, 2007, 2017, 2021 XStream Committers.
+ * Copyright (C) 2006, 2007, 2017, 2021, 2022 XStream Committers.
  * All rights reserved.
  *
  * The software in this package is published under the terms of the BSD
@@ -16,6 +16,8 @@ import com.thoughtworks.acceptance.AbstractAcceptanceTest;
 import com.thoughtworks.xstream.XStream;
 import com.thoughtworks.xstream.io.StreamException;
 
+import java.util.Properties;
+
 import javax.xml.stream.XMLInputFactory;
 import javax.xml.stream.XMLOutputFactory;
 import javax.xml.stream.XMLStreamException;
@@ -47,12 +49,17 @@ public class StaxDriverTest extends AbstractAcceptanceTest {
     }
 
     public void testCanOverloadStaxReaderAndWriterInstantiation() {
+        Properties systemProperties = System.getProperties();
         System.setProperty(XMLInputFactory.class.getName(), MXParserFactory.class.getName());
         System.setProperty(XMLOutputFactory.class.getName(), XMLOutputFactoryBase.class.getName());
-        final MyStaxDriver driver = new MyStaxDriver();
-        xstream = new XStream(driver);
-        assertBothWays("Hi", "<?xml version='1.0' encoding='utf-8'?><string>Hi</string>");
-        assertTrue(driver.createStaxReaderCalled);
-        assertTrue(driver.createStaxWriterCalled);
+        try {
+            final MyStaxDriver driver = new MyStaxDriver();
+            xstream = new XStream(driver);
+            assertBothWays("Hi", "<?xml version='1.0' encoding='utf-8'?><string>Hi</string>");
+            assertTrue(driver.createStaxReaderCalled);
+            assertTrue(driver.createStaxWriterCalled);
+        } finally {
+            System.setProperties(systemProperties);
+        }
     }
 }
